"""
********************************************************************************
* Name: gsshapy
* Author: Nathan Swain
* Created On: Mar 18, 2013
* License: BSD 2-Clause
********************************************************************************
"""
from .util import log_to_file, log_to_console, version

__version__ = version()
